.. _distribution:

******************************************************************
Distribution functions (`plasmapy.formulary.distribution`)
******************************************************************

.. currentmodule:: plasmapy.formulary.distribution

.. automodapi:: plasmapy.formulary.distribution

Examples
========

.. nbgallery::
    :caption: Examples

    /notebooks/formulary/distribution
    /notebooks/formulary/thermal_speed
